@@ -9,9 +9,11 @@ from tonclient.types import (
     CallSet,
     ParamsOfEncodeMessage,
     Signer,
+    ExecutionOptions,
     ParamsOfRunTvm,
 )
 
+from tvmbase.exceptions import ClientRunLocalException
 from tvmbase.models.network import Network
 from tvmbase.utils.singleton import SingletonMeta
 
@@ -28,7 +30,7 @@ class Client(TonClient, metaclass=SingletonMeta):
 
     @staticmethod
     def create_config(network: Network) -> ClientConfig:
-        network_config = NetworkConfig(endpoints=network.value.endpoints)
+        network_config = NetworkConfig(endpoints=network.endpoints)
         return ClientConfig(network=network_config)
 
     async def run_local(
@@ -38,6 +40,8 @@ class Client(TonClient, metaclass=SingletonMeta):
             account: 'Account' = None,
             account_params: (str, str) = None,
             params: dict = None,
+            auto_answer_id: bool = True,
+            execution_options: dict = None,
             parse: bool = False,
     ) -> dict | Any:
         """
@@ -51,6 +55,10 @@ class Client(TonClient, metaclass=SingletonMeta):
         else:
             address, account_boc = account_params
 
+        if auto_answer_id:
+            params = params or dict()
+            self._set_answer_id(abi, method, params)
+
         abi = Abi.Contract(abi)
         call_set = CallSet(function_name=method, input=params)
         message_params = ParamsOfEncodeMessage(
@@ -61,17 +69,37 @@ class Client(TonClient, metaclass=SingletonMeta):
         )
         message = await self.abi.encode_message(params=message_params)
 
-        run_params = ParamsOfRunTvm(message=message.message, account=account_boc, abi=abi)
+        if execution_options is not None:
+            execution_options = ExecutionOptions(**execution_options)
+
+        run_params = ParamsOfRunTvm(
+            message=message.message,
+            account=account_boc,
+            abi=abi,
+            execution_options=execution_options,
+        )
         result = await self.tvm.run_tvm(params=run_params)
         decoded = result.decoded.output
 
         if parse:
             if len(decoded) != 1:
-                raise Exception('Must be exact one output param for automatic parse')
+                raise ClientRunLocalException('Must be exact one output param for automatic parse')
             return decoded.popitem()[1]
         else:
             return decoded
 
+    @staticmethod
+    def _set_answer_id(abi_contract: AbiContract, method: str, params: dict):
+        function = next(filter(
+            lambda f: f.name == method,
+            abi_contract.functions
+        ))
+        if len(function.inputs) == 0:
+            return
+        first_arg_name = function.inputs[0].name
+        if (first_arg_name in ('answerId', '_answer_id')) and (first_arg_name not in params):
+            params[first_arg_name] = 0
+
     # todo
     # async def emulate_local(
     #         self,
